Index: uspace/lib/ext4/libext4_superblock.c
===================================================================
--- uspace/lib/ext4/libext4_superblock.c	(revision 9fc72fb314cf66351b5a63be91b03fb4d04d51ea)
+++ uspace/lib/ext4/libext4_superblock.c	(revision 2226cc3f54a123ec5232808339e4df519bb96f48)
@@ -357,6 +357,8 @@
 }
 
-/** TODO comment
- *
+/** Get filesystem state.
+ *
+ * @param sb		superblock
+ * @return			filesystem state
  */
 uint16_t ext4_superblock_get_state(ext4_superblock_t *sb)
@@ -365,6 +367,8 @@
 }
 
-/** TODO comment
- *
+/** Set filesystem state.
+ *
+ * @param sb		superblock
+ * @param state		filesystem state
  */
 void ext4_superblock_set_state(ext4_superblock_t *sb, uint16_t state)
@@ -373,6 +377,8 @@
 }
 
-/** TODO comment
- *
+/** Get behavior code when errors detected.
+ *
+ * @param sb		superblock
+ * @return			behavior code
  */
 uint16_t ext4_superblock_get_errors(ext4_superblock_t *sb)
@@ -381,6 +387,8 @@
 }
 
-/** TODO comment
- *
+/** Set behavior code when errors detected.
+ *
+ * @param sb		superblock
+ * @param errors 	behavior code
  */
 void ext4_superblock_set_errors(ext4_superblock_t *sb, uint16_t errors)
@@ -389,6 +397,8 @@
 }
 
-/** TODO comment
- *
+/** Get minor revision level of the filesystem.
+ *
+ * @param sb		superblock
+ * @return			minor revision level
  */
 uint16_t ext4_superblock_get_minor_rev_level(ext4_superblock_t *sb)
@@ -397,6 +407,8 @@
 }
 
-/** TODO comment
- *
+/** Set minor revision level of the filesystem.
+ *
+ * @param sb		superblock
+ * @param level 	minor revision level
  */
 void ext4_superblock_set_minor_rev_level(ext4_superblock_t *sb, uint16_t level)
@@ -405,6 +417,8 @@
 }
 
-/** TODO comment
- *
+/** Get time of the last filesystem check.
+ *
+ * @param sb		superblock
+ * @return			time of the last check (POSIX)
  */
 uint32_t ext4_superblock_get_last_check_time(ext4_superblock_t *sb)
@@ -413,6 +427,8 @@
 }
 
-/** TODO comment
- *
+/** Set time of the last filesystem check.
+ *
+ * @param sb		superblock
+ * @param time		time of the last check (POSIX)
  */
 void ext4_superblock_set_last_check_time(ext4_superblock_t *sb, uint32_t time)
@@ -421,6 +437,8 @@
 }
 
-/** TODO comment
- *
+/** Get maximum time interval between two filesystem checks.
+ *
+ * @param sb		superblock
+ * @return			time interval between two check (POSIX)
  */
 uint32_t ext4_superblock_get_check_interval(ext4_superblock_t *sb){
@@ -428,6 +446,8 @@
 }
 
-/** TODO comment
- *
+/** Set maximum time interval between two filesystem checks.
+ *
+ * @param sb			superblock
+ * @param interval		time interval between two check (POSIX)
  */
 void ext4_superblock_set_check_interval(ext4_superblock_t *sb, uint32_t interval)
@@ -436,6 +456,8 @@
 }
 
-/** TODO comment
- *
+/** Get operation system identifier, on which the filesystem was created.
+ *
+ * @param sb		superblock
+ * @return			operation system identifier
  */
 uint32_t ext4_superblock_get_creator_os(ext4_superblock_t *sb)
@@ -444,6 +466,8 @@
 }
 
-/** TODO comment
- *
+/** Set operation system identifier, on which the filesystem was created.
+ *
+ * @param sb		superblock
+ * @param os		operation system identifier
  */
 void ext4_superblock_set_creator_os(ext4_superblock_t *sb, uint32_t os)
@@ -452,6 +476,8 @@
 }
 
-/** TODO comment
- *
+/** Get revision level of the filesystem.
+ *
+ * @param sb		superblock
+ * @return			revision level
  */
 uint32_t ext4_superblock_get_rev_level(ext4_superblock_t *sb)
@@ -460,6 +486,8 @@
 }
 
-/** TODO comment
- *
+/** Set revision level of the filesystem.
+ *
+ * @param sb		superblock
+ * @param level 	revision level
  */
 void ext4_superblock_set_rev_level(ext4_superblock_t *sb, uint32_t level)
@@ -468,6 +496,8 @@
 }
 
-/** TODO comment
- *
+/** Get default user id for reserved blocks.
+ *
+ * @param sb		superblock
+ * @return			default user id for reserved blocks.
  */
 uint16_t ext4_superblock_get_def_resuid(ext4_superblock_t *sb)
@@ -476,6 +506,8 @@
 }
 
-/** TODO comment
- *
+/** Set default user id for reserved blocks.
+ *
+ * @param sb		superblock
+ * @param uid		default user id for reserved blocks.
  */
 void ext4_superblock_set_def_resuid(ext4_superblock_t *sb, uint16_t uid)
@@ -484,6 +516,8 @@
 }
 
-/** TODO comment
- *
+/** Get default group id for reserved blocks.
+ *
+ * @param sb		superblock
+ * @return			default group id for reserved blocks.
  */
 uint16_t ext4_superblock_get_def_resgid(ext4_superblock_t *sb)
@@ -492,6 +526,8 @@
 }
 
-/** TODO comment
- *
+/** Set default group id for reserved blocks.
+ *
+ * @param sb		superblock
+ * @param gid		default group id for reserved blocks.
  */
 void ext4_superblock_set_def_resgid(ext4_superblock_t *sb, uint16_t gid)
@@ -500,6 +536,8 @@
 }
 
-/** TODO comment
- *
+/** Get index of the first i-node, which can be used for allocation.
+ *
+ * @param sb		superblock
+ * @return			i-node index
  */
 uint32_t ext4_superblock_get_first_inode(ext4_superblock_t *sb)
@@ -508,6 +546,8 @@
 }
 
-/** TODO comment
- *
+/** Set index of the first i-node, which can be used for allocation.
+ *
+ * @param sb			superblock
+ * @param first_inode	i-node index
  */
 void ext4_superblock_set_first_inode(ext4_superblock_t *sb, uint32_t first_inode)
@@ -516,6 +556,10 @@
 }
 
-/** TODO comment
- *
+/** Get size of i-node structure.
+ *
+ * For the oldest revision return constant number.
+ *
+ * @param sb			superblock
+ * @return				size of i-node structure
  */
 uint16_t ext4_superblock_get_inode_size(ext4_superblock_t *sb)
@@ -527,6 +571,8 @@
 }
 
-/** TODO comment
- *
+/** Set size of i-node structure.
+ *
+ * @param sb			superblock
+ * @param size			size of i-node structure
  */
 void ext4_superblock_set_inode_size(ext4_superblock_t *sb, uint16_t size)
@@ -535,22 +581,28 @@
 }
 
-/** TODO comment
- *
- */
-uint16_t ext4_superblock_get_block_group_number(ext4_superblock_t *sb)
-{
-	return uint16_t_le2host(sb->block_group_number);
-}
-
-/** TODO comment
- *
- */
-void ext4_superblock_set_block_group_number(ext4_superblock_t *sb, uint16_t bg)
-{
-	sb->block_group_number = host2uint16_t_le(bg);
-}
-
-/** TODO comment
- *
+/** Get index of block group, where superblock copy is located.
+ *
+ * @param sb			superblock
+ * @return				block group index
+ */
+uint16_t ext4_superblock_get_block_group_index(ext4_superblock_t *sb)
+{
+	return uint16_t_le2host(sb->block_group_index);
+}
+
+/** Set index of block group, where superblock copy is located.
+ *
+ * @param sb			superblock
+ * @param bgid			block group index
+ */
+void ext4_superblock_set_block_group_index(ext4_superblock_t *sb, uint16_t bgid)
+{
+	sb->block_group_index = host2uint16_t_le(bgid);
+}
+
+/** Get compatible features supported by the filesystem.
+ *
+ * @param sb		superblock
+ * @return			compatible features bitmap
  */
 uint32_t ext4_superblock_get_features_compatible(ext4_superblock_t *sb)
@@ -559,6 +611,8 @@
 }
 
-/** TODO comment
- *
+/** Set compatible features supported by the filesystem.
+ *
+ * @param sb			superblock
+ * @param features		compatible features bitmap
  */
 void ext4_superblock_set_features_compatible(ext4_superblock_t *sb, uint32_t features)
@@ -567,6 +621,8 @@
 }
 
-/** TODO comment
- *
+/** Get incompatible features supported by the filesystem.
+ *
+ * @param sb		superblock
+ * @return			incompatible features bitmap
  */
 uint32_t ext4_superblock_get_features_incompatible(ext4_superblock_t *sb)
@@ -575,6 +631,8 @@
 }
 
-/** TODO comment
- *
+/** Set incompatible features supported by the filesystem.
+ *
+ * @param sb			superblock
+ * @param features		incompatible features bitmap
  */
 void ext4_superblock_set_features_incompatible(ext4_superblock_t *sb, uint32_t features)
@@ -583,6 +641,8 @@
 }
 
-/** TODO comment
- *
+/** Get compatible features supported by the filesystem.
+ *
+ * @param sb		superblock
+ * @return			read-only compatible features bitmap
  */
 uint32_t ext4_superblock_get_features_read_only(ext4_superblock_t *sb)
@@ -591,6 +651,8 @@
 }
 
-/** TODO comment
- *
+/** Set compatible features supported by the filesystem.
+ *
+ * @param sb			superblock
+ * @param feature		read-only compatible features bitmap
  */
 void ext4_superblock_set_features_read_only(ext4_superblock_t *sb, uint32_t features)
@@ -599,6 +661,8 @@
 }
 
-/** TODO comment
- *
+/** Get UUID of the filesystem.
+ *
+ * @param sb		superblock
+ * @return 			pointer to UUID array
  */
 const uint8_t * ext4_superblock_get_uuid(ext4_superblock_t *sb)
@@ -607,6 +671,8 @@
 }
 
-/** TODO comment
- *
+/** Set UUID of the filesystem.
+ *
+ * @param sb		superblock
+ * @param uuid		pointer to UUID array
  */
 void ext4_superblock_set_uuid(ext4_superblock_t *sb, const uint8_t *uuid)
@@ -615,4 +681,9 @@
 }
 
+/** Get name of the filesystem volume.
+ *
+ * @param sb		superblock
+ * @return			name of the volume
+ */
 const char * ext4_superblock_get_volume_name(ext4_superblock_t *sb)
 {
@@ -620,6 +691,8 @@
 }
 
-/** TODO comment
- *
+/** Set name of the filesystem volume.
+ *
+ * @param sb		superblock
+ * @param name		new name of the volume
  */
 void ext4_superblock_set_volume_name(ext4_superblock_t *sb, const char *name)
@@ -628,6 +701,8 @@
 }
 
-/** TODO comment
- *
+/** Get name of the directory, where this filesystem was mounted at last.
+ *
+ * @param sb		superblock
+ * @return 			directory name
  */
 const char * ext4_superblock_get_last_mounted(ext4_superblock_t *sb)
@@ -636,6 +711,8 @@
 }
 
-/** TODO comment
- *
+/** Set name of the directory, where this filesystem was mounted at last.
+ *
+ * @param sb		superblock
+ * @param last		directory name
  */
 void ext4_superblock_set_last_mounted(ext4_superblock_t *sb, const char *last)
@@ -644,6 +721,10 @@
 }
 
-/** TODO comment
- *
+/** Get last orphaned i-node index.
+ *
+ * Orphans are stored in linked list.
+ *
+ * @param sb		superblock
+ * @return			last orphaned i-node index
  */
 uint32_t ext4_superblock_get_last_orphan(ext4_superblock_t *sb)
@@ -652,6 +733,10 @@
 }
 
-/** TODO comment
- *
+/** Set last orphaned i-node index.
+ *
+ * Orphans are stored in linked list.
+ *
+ * @param sb			superblock
+ * @param last_orphan	last orphaned i-node index
  */
 void ext4_superblock_set_last_orphan(ext4_superblock_t *sb, uint32_t last_orphan)
@@ -660,14 +745,28 @@
 }
 
-/** TODO comment
- *
- */
-uint32_t* ext4_superblock_get_hash_seed(ext4_superblock_t *sb)
+/** Get hash seed for directory index hash function.
+ *
+ * @param sb		superblock
+ * @return			hash seed pointer
+ */
+const uint32_t * ext4_superblock_get_hash_seed(ext4_superblock_t *sb)
 {
 	return sb->hash_seed;
 }
 
-/** TODO comment
- *
+/** Set hash seed for directory index hash function.
+ *
+ * @param sb		superblock
+ * @param seed		hash seed pointer
+ */
+void ext4_superblock_set_hash_seed(ext4_superblock_t *sb, const uint32_t *seed)
+{
+	memcpy(sb->hash_seed, seed, sizeof(sb->hash_seed));
+}
+
+/** Get default version of the hash algorithm version for directory index.
+ *
+ * @param sb		superblock
+ * @return			default hash version
  */
 uint8_t ext4_superblock_get_default_hash_version(ext4_superblock_t *sb)
@@ -676,6 +775,8 @@
 }
 
-/** TODO comment
- *
+/** Set default version of the hash algorithm version for directory index.
+ *
+ * @param sb		superblock
+ * @param version	default hash version
  */
 void ext4_superblock_set_default_hash_version(ext4_superblock_t *sb, uint8_t version)
@@ -684,6 +785,10 @@
 }
 
-/** TODO comment
- *
+/** Get size of block group descriptor structure.
+ *
+ * Output value is checked for minimal size.
+ *
+ * @param sb		superblock
+ * @return			size of block group descriptor
  */
 uint16_t ext4_superblock_get_desc_size(ext4_superblock_t *sb)
@@ -698,14 +803,24 @@
 }
 
-/** TODO comment
- *
+/** Set size of block group descriptor structure.
+ *
+ * Input value is checked for minimal size.
+ *
+ * @param sb		superblock
+ * @param size 		size of block group descriptor
  */
 void ext4_superblock_set_desc_size(ext4_superblock_t *sb, uint16_t size)
 {
+	if (size < EXT4_BLOCK_MIN_GROUP_DESCRIPTOR_SIZE) {
+		sb->desc_size = host2uint16_t_le(EXT4_BLOCK_MIN_GROUP_DESCRIPTOR_SIZE);
+	}
+
 	sb->desc_size = host2uint16_t_le(size);
 }
 
-/** TODO comment
- *
+/** Get superblock flags.
+ *
+ * @param sb		superblock
+ * @return 			flags from the superblock
  */
 uint32_t ext4_superblock_get_flags(ext4_superblock_t *sb)
@@ -714,6 +829,8 @@
 }
 
-/** TODO comment
- *
+/** Set superblock flags.
+ *
+ * @param sb		superblock
+ * @param flags		flags for the superblock
  */
 void ext4_superblock_set_flags(ext4_superblock_t *sb, uint32_t flags)
@@ -721,5 +838,4 @@
 	sb->flags = host2uint32_t_le(flags);
 }
-
 
 /*
@@ -727,6 +843,9 @@
  */
 
-/** TODO comment
- *
+/** Check if superblock has specified flag.
+ *
+ * @param sb			superblock
+ * @param flag			flag to be checked
+ * @return				true, if superblock has the flag
  */
 bool ext4_superblock_has_flag(ext4_superblock_t *sb, uint32_t flag)
@@ -738,6 +857,9 @@
 }
 
-/** TODO comment
- *
+/** Check if filesystem supports compatible feature.
+ *
+ * @param sb			superblock
+ * @param feature		feature to be checked
+ * @return				true, if filesystem supports the feature
  */
 bool ext4_superblock_has_feature_compatible(ext4_superblock_t *sb, uint32_t feature)
@@ -749,6 +871,9 @@
 }
 
-/** TODO comment
- *
+/** Check if filesystem supports incompatible feature.
+ *
+ * @param sb			superblock
+ * @param feature		feature to be checked
+ * @return				true, if filesystem supports the feature
  */
 bool ext4_superblock_has_feature_incompatible(ext4_superblock_t *sb, uint32_t feature)
@@ -760,6 +885,9 @@
 }
 
-/** TODO comment
- *
+/** Check if filesystem supports read-only compatible feature.
+ *
+ * @param sb			superblock
+ * @param feature		feature to be checked
+ * @return				true, if filesystem supports the feature
  */
 bool ext4_superblock_has_feature_read_only(ext4_superblock_t *sb, uint32_t feature)
@@ -771,12 +899,16 @@
 }
 
-/** TODO comment
- *
+/** Read superblock directly from block device.
+ *
+ * @param service_id		block device identifier
+ * @param sb				output pointer to memory structure
+ * @return					error code.
  */
 int ext4_superblock_read_direct(service_id_t service_id,
-    ext4_superblock_t **superblock)
+    ext4_superblock_t **sb)
 {
 	int rc;
 
+	// Allocated memory for superblock structure
 	void *data = malloc(EXT4_SUPERBLOCK_SIZE);
 	if (data == NULL) {
@@ -784,4 +916,5 @@
 	}
 
+	// Read data from block device
 	rc = block_read_bytes_direct(service_id, EXT4_SUPERBLOCK_OFFSET,
 	    EXT4_SUPERBLOCK_SIZE, data);
@@ -792,11 +925,15 @@
 	}
 
-	(*superblock) = data;
+	// Set output value
+	(*sb) = data;
 
 	return EOK;
 }
 
-/** TODO comment
- *
+/** Write superblock structure directly to block device.
+ *
+ * @param service_id		block device identifier
+ * @param sb				superblock to be written
+ * @return					error code
  */
 int ext4_superblock_write_direct(service_id_t service_id,
@@ -806,17 +943,21 @@
 	uint32_t phys_block_size;
 
+	// Load physical block size from block device
 	rc = block_get_bsize(service_id, &phys_block_size);
 	if (rc != EOK) {
-		// TODO error
 		return rc;
 	}
 
+	// Compute address of the first block
 	uint64_t first_block = EXT4_SUPERBLOCK_OFFSET / phys_block_size;
+	// Compute number of block to write
 	uint32_t block_count = EXT4_SUPERBLOCK_SIZE / phys_block_size;
 
+	// Check alignment
 	if (EXT4_SUPERBLOCK_SIZE % phys_block_size) {
 		block_count++;
 	}
 
+	// Write data
 	return block_write_direct(service_id, first_block, block_count, sb);
 
@@ -841,6 +982,8 @@
 }
 
-/** TODO comment
- *
+/** Compute number of block groups in the filesystem.
+ *
+ * @param sb		superblock
+ * @return			number of block groups
  */
 uint32_t ext4_superblock_get_block_group_count(ext4_superblock_t *sb)
@@ -859,6 +1002,9 @@
 }
 
-/** TODO comment
- *
+/** Compute number of blocks in specified block group.
+ *
+ * @param sb			superblock
+ * @param bgid			block group index
+ * @return				number of blocks
  */
 uint32_t ext4_superblock_get_blocks_in_group(ext4_superblock_t *sb, uint32_t bgid)
@@ -876,6 +1022,9 @@
 }
 
-/** TODO comment
- *
+/** Compute number of i-nodes in specified block group.
+ *
+ * @param sb		superblock
+ * @param bgid		block group index
+ * @return			number of i-nodes
  */
 uint32_t ext4_superblock_get_inodes_in_group(ext4_superblock_t *sb, uint32_t bgid)
Index: uspace/lib/ext4/libext4_superblock.h
===================================================================
--- uspace/lib/ext4/libext4_superblock.h	(revision 9fc72fb314cf66351b5a63be91b03fb4d04d51ea)
+++ uspace/lib/ext4/libext4_superblock.h	(revision 2226cc3f54a123ec5232808339e4df519bb96f48)
@@ -91,6 +91,6 @@
 extern uint16_t ext4_superblock_get_inode_size(ext4_superblock_t *);
 extern void ext4_superblock_set_inode_size(ext4_superblock_t *, uint16_t);
-extern uint16_t ext4_superblock_get_block_group_number(ext4_superblock_t *);
-extern void ext4_superblock_set_block_group_number(ext4_superblock_t *, uint16_t);
+extern uint16_t ext4_superblock_get_block_group_index(ext4_superblock_t *);
+extern void ext4_superblock_set_block_group_index(ext4_superblock_t *, uint16_t);
 extern uint32_t	ext4_superblock_get_features_compatible(ext4_superblock_t *);
 extern void	ext4_superblock_set_features_compatible(ext4_superblock_t *, uint32_t);
@@ -118,5 +118,6 @@
 extern uint32_t ext4_superblock_get_last_orphan(ext4_superblock_t *);
 extern void ext4_superblock_set_last_orphan(ext4_superblock_t *, uint32_t);
-extern uint32_t* ext4_superblock_get_hash_seed(ext4_superblock_t *);
+extern const uint32_t * ext4_superblock_get_hash_seed(ext4_superblock_t *);
+extern void ext4_superblock_set_hash_seed(ext4_superblock_t *, const uint32_t *);
 extern uint8_t ext4_superblock_get_default_hash_version(ext4_superblock_t *);
 extern void ext4_superblock_set_default_hash_version(ext4_superblock_t *, uint8_t);
Index: uspace/lib/ext4/libext4_types.h
===================================================================
--- uspace/lib/ext4/libext4_types.h	(revision 9fc72fb314cf66351b5a63be91b03fb4d04d51ea)
+++ uspace/lib/ext4/libext4_types.h	(revision 2226cc3f54a123ec5232808339e4df519bb96f48)
@@ -56,5 +56,5 @@
 	uint16_t max_mount_count; // Maximal mount count
 	uint16_t magic; // Magic signature
-	uint16_t state; // File system state
+	uint16_t state; // Filesystem state
 	uint16_t errors; // Behaviour when detecting errors
 	uint16_t minor_rev_level; // Minor revision level
@@ -69,5 +69,5 @@
 	uint32_t first_inode; // First non-reserved inode
 	uint16_t inode_size; // Size of inode structure
-	uint16_t block_group_number; // Block group number of this superblock
+	uint16_t block_group_index; // Block group index of this superblock
 	uint32_t features_compatible; // Compatible feature set
 	uint32_t features_incompatible; // Incompatible feature set
@@ -136,4 +136,5 @@
 } __attribute__((packed)) ext4_superblock_t;
 
+
 #define EXT4_SUPERBLOCK_MAGIC		0xEF53
 #define EXT4_SUPERBLOCK_SIZE		1024
@@ -146,9 +147,26 @@
  * Misc. filesystem flags
  */
-#define EXT4_SUPERBLOCK_FLAGS_SIGNED_HASH	0x0001  /* Signed dirhash in use */
-#define EXT4_SUPERBLOCK_FLAGS_UNSIGNED_HASH	0x0002  /* Unsigned dirhash in use */
-#define EXT4_SUPERBLOCK_FLAGS_TEST_FILESYS	0x0004  /* to test development code */
-
-/* Compatible features */
+#define EXT4_SUPERBLOCK_FLAGS_SIGNED_HASH	0x0001  // Signed dirhash in use
+#define EXT4_SUPERBLOCK_FLAGS_UNSIGNED_HASH	0x0002  // Unsigned dirhash in use
+#define EXT4_SUPERBLOCK_FLAGS_TEST_FILESYS	0x0004  // to test development code
+
+/*
+ * Filesystem states
+ */
+#define EXT4_SUPERBLOCK_STATE_VALID_FS		0x0001  // Unmounted cleanly
+#define EXT4_SUPERBLOCK_STATE_ERROR_FS		0x0002  // Errors detected
+#define EXT4_SUPERBLOCK_STATE_ORPHAN_FS		0x0004  // Orphans being recovered
+
+/*
+ * Behaviour when errors detected
+ */
+#define EXT4_SUPERBLOCK_ERRORS_CONTINUE		1 // Continue execution
+#define EXT4_SUPERBLOCK_ERRORS_RO			2 // Remount fs read-only
+#define EXT4_SUPERBLOCK_ERRORS_PANIC		3 // Panic
+#define EXT4_SUPERBLOCK_ERRORS_DEFAULT		EXT4_ERRORS_CONTINUE
+
+/*
+ * Compatible features
+ */
 #define EXT4_FEATURE_COMPAT_DIR_PREALLOC        0x0001
 #define EXT4_FEATURE_COMPAT_IMAGIC_INODES       0x0002
@@ -158,5 +176,7 @@
 #define EXT4_FEATURE_COMPAT_DIR_INDEX           0x0020
 
-/* Read-only compatible features */
+/*
+ * Read-only compatible features
+ */
 #define EXT4_FEATURE_RO_COMPAT_SPARSE_SUPER     0x0001
 #define EXT4_FEATURE_RO_COMPAT_LARGE_FILE       0x0002
@@ -167,5 +187,7 @@
 #define EXT4_FEATURE_RO_COMPAT_EXTRA_ISIZE      0x0040
 
-/* Incompatible features */
+/*
+ * Incompatible features
+ */
 #define EXT4_FEATURE_INCOMPAT_COMPRESSION       0x0001
 #define EXT4_FEATURE_INCOMPAT_FILETYPE          0x0002
